@@ -231,7 +231,7 @@ static bt_property_t prop_emu_default_set[] = {
 	{ BT_PROPERTY_UUIDS, sizeof(emu_uuids_val), &emu_uuids_val },
 };
 
-static bt_property_t prop_emu_remote_bles_default_set[] = {
+static bt_property_t prop_emu_remote_ble_default_set[] = {
 	{ BT_PROPERTY_BDADDR, sizeof(emu_remote_bdaddr_val),
 						&emu_remote_bdaddr_val },
 	{ BT_PROPERTY_TYPE_OF_DEVICE, sizeof(emu_remote_tod_ble_val),
@@ -240,7 +240,7 @@ static bt_property_t prop_emu_remote_bles_default_set[] = {
 						&emu_remote_ble_rssi_val },
 };
 
-static bt_property_t prop_emu_remotes_default_set[] = {
+static bt_property_t prop_emu_remote_bredr_default_set[] = {
 	{ BT_PROPERTY_BDADDR, sizeof(emu_remote_bdaddr_val),
 						&emu_remote_bdaddr_val },
 	{ BT_PROPERTY_TYPE_OF_DEVICE, sizeof(emu_remote_type_val),
@@ -249,6 +249,11 @@ static bt_property_t prop_emu_remotes_default_set[] = {
 						&emu_remote_rssi_val },
 };
 
+static bt_property_t prop_emu_remote_any_default_set[] = {
+	{ BT_PROPERTY_BDADDR, sizeof(emu_remote_bdaddr_val),
+						&emu_remote_bdaddr_val },
+};
+
 static bt_property_t prop_emu_remote_bles_query_set[] = {
 	{ BT_PROPERTY_TYPE_OF_DEVICE, sizeof(emu_remote_tod_ble_val),
 						&emu_remote_tod_ble_val },
@@ -644,11 +649,11 @@ static struct test_case test_cases[] = {
 	TEST_CASE_BREDRLE("Bluetooth Discovery Device Found",
 		ACTION_SUCCESS(bluetooth_enable_action, NULL),
 		CALLBACK_STATE(CB_BT_ADAPTER_STATE_CHANGED, BT_STATE_ON),
-		ACTION_SUCCESS(emu_setup_powered_remote_action, NULL),
 		ACTION_SUCCESS(bt_start_discovery_action, NULL),
 		CALLBACK_STATE(CB_BT_DISCOVERY_STATE_CHANGED,
 							BT_DISCOVERY_STARTED),
-		CALLBACK_DEVICE_FOUND(prop_emu_remote_bles_default_set, 3),
+		ACTION_SUCCESS(emu_setup_powered_remote_action, NULL),
+		CALLBACK_DEVICE_FOUND(prop_emu_remote_ble_default_set, 3),
 		ACTION_SUCCESS(bt_cancel_discovery_action, NULL),
 		CALLBACK_STATE(CB_BT_DISCOVERY_STATE_CHANGED,
 							BT_DISCOVERY_STOPPED),
@@ -656,10 +661,11 @@ static struct test_case test_cases[] = {
 	TEST_CASE_BREDRLE("Bluetooth Device Get Props - Success",
 		ACTION_SUCCESS(bluetooth_enable_action, NULL),
 		CALLBACK_STATE(CB_BT_ADAPTER_STATE_CHANGED, BT_STATE_ON),
-		ACTION_SUCCESS(emu_setup_powered_remote_action, NULL),
 		ACTION_SUCCESS(bt_start_discovery_action, NULL),
 		CALLBACK_STATE(CB_BT_DISCOVERY_STATE_CHANGED,
 							BT_DISCOVERY_STARTED),
+		ACTION_SUCCESS(emu_setup_powered_remote_action, NULL),
+		CALLBACK_DEVICE_FOUND(prop_emu_remote_any_default_set, 1),
 		ACTION_SUCCESS(bt_cancel_discovery_action, NULL),
 		CALLBACK_STATE(CB_BT_DISCOVERY_STATE_CHANGED,
 							BT_DISCOVERY_STOPPED),
@@ -670,10 +676,11 @@ static struct test_case test_cases[] = {
 	TEST_CASE_BREDRLE("Bluetooth Device Get BDNAME - Success",
 		ACTION_SUCCESS(bluetooth_enable_action, NULL),
 		CALLBACK_STATE(CB_BT_ADAPTER_STATE_CHANGED, BT_STATE_ON),
-		ACTION_SUCCESS(emu_setup_powered_remote_action, NULL),
 		ACTION_SUCCESS(bt_start_discovery_action, NULL),
 		CALLBACK_STATE(CB_BT_DISCOVERY_STATE_CHANGED,
 							BT_DISCOVERY_STARTED),
+		ACTION_SUCCESS(emu_setup_powered_remote_action, NULL),
+		CALLBACK_DEVICE_FOUND(prop_emu_remote_any_default_set, 1),
 		ACTION_SUCCESS(bt_cancel_discovery_action, NULL),
 		CALLBACK_STATE(CB_BT_DISCOVERY_STATE_CHANGED,
 							BT_DISCOVERY_STOPPED),
@@ -684,10 +691,11 @@ static struct test_case test_cases[] = {
 	TEST_CASE_BREDRLE("Bluetooth Device Get UUIDS - Success",
 		ACTION_SUCCESS(bluetooth_enable_action, NULL),
 		CALLBACK_STATE(CB_BT_ADAPTER_STATE_CHANGED, BT_STATE_ON),
-		ACTION_SUCCESS(emu_setup_powered_remote_action, NULL),
 		ACTION_SUCCESS(bt_start_discovery_action, NULL),
 		CALLBACK_STATE(CB_BT_DISCOVERY_STATE_CHANGED,
 							BT_DISCOVERY_STARTED),
+		ACTION_SUCCESS(emu_setup_powered_remote_action, NULL),
+		CALLBACK_DEVICE_FOUND(prop_emu_remote_any_default_set, 1),
 		ACTION_SUCCESS(bt_cancel_discovery_action, NULL),
 		CALLBACK_STATE(CB_BT_DISCOVERY_STATE_CHANGED,
 							BT_DISCOVERY_STOPPED),
@@ -698,10 +706,11 @@ static struct test_case test_cases[] = {
 	TEST_CASE_BREDRLE("Bluetooth Device Get COD - Success",
 		ACTION_SUCCESS(bluetooth_enable_action, NULL),
 		CALLBACK_STATE(CB_BT_ADAPTER_STATE_CHANGED, BT_STATE_ON),
-		ACTION_SUCCESS(emu_setup_powered_remote_action, NULL),
 		ACTION_SUCCESS(bt_start_discovery_action, NULL),
 		CALLBACK_STATE(CB_BT_DISCOVERY_STATE_CHANGED,
 							BT_DISCOVERY_STARTED),
+		ACTION_SUCCESS(emu_setup_powered_remote_action, NULL),
+		CALLBACK_DEVICE_FOUND(prop_emu_remote_any_default_set, 1),
 		ACTION_SUCCESS(bt_cancel_discovery_action, NULL),
 		CALLBACK_STATE(CB_BT_DISCOVERY_STATE_CHANGED,
 							BT_DISCOVERY_STOPPED),
@@ -712,10 +721,11 @@ static struct test_case test_cases[] = {
 	TEST_CASE_BREDRLE("Bluetooth Device Get TOD - Success",
 		ACTION_SUCCESS(bluetooth_enable_action, NULL),
 		CALLBACK_STATE(CB_BT_ADAPTER_STATE_CHANGED, BT_STATE_ON),
-		ACTION_SUCCESS(emu_setup_powered_remote_action, NULL),
 		ACTION_SUCCESS(bt_start_discovery_action, NULL),
 		CALLBACK_STATE(CB_BT_DISCOVERY_STATE_CHANGED,
 							BT_DISCOVERY_STARTED),
+		ACTION_SUCCESS(emu_setup_powered_remote_action, NULL),
+		CALLBACK_DEVICE_FOUND(prop_emu_remote_any_default_set, 1),
 		ACTION_SUCCESS(bt_cancel_discovery_action, NULL),
 		CALLBACK_STATE(CB_BT_DISCOVERY_STATE_CHANGED,
 							BT_DISCOVERY_STOPPED),
@@ -726,10 +736,11 @@ static struct test_case test_cases[] = {
 	TEST_CASE_BREDRLE("Bluetooth Device Get RSSI - Success",
 		ACTION_SUCCESS(bluetooth_enable_action, NULL),
 		CALLBACK_STATE(CB_BT_ADAPTER_STATE_CHANGED, BT_STATE_ON),
-		ACTION_SUCCESS(emu_setup_powered_remote_action, NULL),
 		ACTION_SUCCESS(bt_start_discovery_action, NULL),
 		CALLBACK_STATE(CB_BT_DISCOVERY_STATE_CHANGED,
 							BT_DISCOVERY_STARTED),
+		ACTION_SUCCESS(emu_setup_powered_remote_action, NULL),
+		CALLBACK_DEVICE_FOUND(prop_emu_remote_any_default_set, 1),
 		ACTION_SUCCESS(bt_cancel_discovery_action, NULL),
 		CALLBACK_STATE(CB_BT_DISCOVERY_STATE_CHANGED,
 							BT_DISCOVERY_STOPPED),
@@ -740,10 +751,11 @@ static struct test_case test_cases[] = {
 	TEST_CASE_BREDRLE("Bluetooth Device Get TIMESTAMP - Success",
 		ACTION_SUCCESS(bluetooth_enable_action, NULL),
 		CALLBACK_STATE(CB_BT_ADAPTER_STATE_CHANGED, BT_STATE_ON),
-		ACTION_SUCCESS(emu_setup_powered_remote_action, NULL),
 		ACTION_SUCCESS(bt_start_discovery_action, NULL),
 		CALLBACK_STATE(CB_BT_DISCOVERY_STATE_CHANGED,
 							BT_DISCOVERY_STARTED),
+		ACTION_SUCCESS(emu_setup_powered_remote_action, NULL),
+		CALLBACK_DEVICE_FOUND(prop_emu_remote_any_default_set, 1),
 		ACTION_SUCCESS(bt_cancel_discovery_action, NULL),
 		CALLBACK_STATE(CB_BT_DISCOVERY_STATE_CHANGED,
 							BT_DISCOVERY_STOPPED),
@@ -754,10 +766,11 @@ static struct test_case test_cases[] = {
 	TEST_CASE_BREDRLE("Bluetooth Device Get BDADDR - Fail",
 		ACTION_SUCCESS(bluetooth_enable_action, NULL),
 		CALLBACK_STATE(CB_BT_ADAPTER_STATE_CHANGED, BT_STATE_ON),
-		ACTION_SUCCESS(emu_setup_powered_remote_action, NULL),
 		ACTION_SUCCESS(bt_start_discovery_action, NULL),
 		CALLBACK_STATE(CB_BT_DISCOVERY_STATE_CHANGED,
 							BT_DISCOVERY_STARTED),
+		ACTION_SUCCESS(emu_setup_powered_remote_action, NULL),
+		CALLBACK_DEVICE_FOUND(prop_emu_remote_any_default_set, 1),
 		ACTION_SUCCESS(bt_cancel_discovery_action, NULL),
 		CALLBACK_STATE(CB_BT_DISCOVERY_STATE_CHANGED,
 							BT_DISCOVERY_STOPPED),
@@ -767,10 +780,11 @@ static struct test_case test_cases[] = {
 	TEST_CASE_BREDRLE("Bluetooth Device Get SCAN_MODE - Fail",
 		ACTION_SUCCESS(bluetooth_enable_action, NULL),
 		CALLBACK_STATE(CB_BT_ADAPTER_STATE_CHANGED, BT_STATE_ON),
-		ACTION_SUCCESS(emu_setup_powered_remote_action, NULL),
 		ACTION_SUCCESS(bt_start_discovery_action, NULL),
 		CALLBACK_STATE(CB_BT_DISCOVERY_STATE_CHANGED,
 							BT_DISCOVERY_STARTED),
+		ACTION_SUCCESS(emu_setup_powered_remote_action, NULL),
+		CALLBACK_DEVICE_FOUND(prop_emu_remote_any_default_set, 1),
 		ACTION_SUCCESS(bt_cancel_discovery_action, NULL),
 		CALLBACK_STATE(CB_BT_DISCOVERY_STATE_CHANGED,
 							BT_DISCOVERY_STOPPED),
@@ -780,10 +794,11 @@ static struct test_case test_cases[] = {
 	TEST_CASE_BREDRLE("Bluetooth Device Get BONDED_DEVICES - Fail",
 		ACTION_SUCCESS(bluetooth_enable_action, NULL),
 		CALLBACK_STATE(CB_BT_ADAPTER_STATE_CHANGED, BT_STATE_ON),
-		ACTION_SUCCESS(emu_setup_powered_remote_action, NULL),
 		ACTION_SUCCESS(bt_start_discovery_action, NULL),
 		CALLBACK_STATE(CB_BT_DISCOVERY_STATE_CHANGED,
 							BT_DISCOVERY_STARTED),
+		ACTION_SUCCESS(emu_setup_powered_remote_action, NULL),
+		CALLBACK_DEVICE_FOUND(prop_emu_remote_any_default_set, 1),
 		ACTION_SUCCESS(bt_cancel_discovery_action, NULL),
 		CALLBACK_STATE(CB_BT_DISCOVERY_STATE_CHANGED,
 							BT_DISCOVERY_STOPPED),
@@ -793,10 +808,11 @@ static struct test_case test_cases[] = {
 	TEST_CASE_BREDRLE("Bluetooth Device Get DISCOVERY_TIMEOUT - Fail",
 		ACTION_SUCCESS(bluetooth_enable_action, NULL),
 		CALLBACK_STATE(CB_BT_ADAPTER_STATE_CHANGED, BT_STATE_ON),
-		ACTION_SUCCESS(emu_setup_powered_remote_action, NULL),
 		ACTION_SUCCESS(bt_start_discovery_action, NULL),
 		CALLBACK_STATE(CB_BT_DISCOVERY_STATE_CHANGED,
 							BT_DISCOVERY_STARTED),
+		ACTION_SUCCESS(emu_setup_powered_remote_action, NULL),
+		CALLBACK_DEVICE_FOUND(prop_emu_remote_any_default_set, 1),
 		ACTION_SUCCESS(bt_cancel_discovery_action, NULL),
 		CALLBACK_STATE(CB_BT_DISCOVERY_STATE_CHANGED,
 							BT_DISCOVERY_STOPPED),
@@ -806,10 +822,11 @@ static struct test_case test_cases[] = {
 	TEST_CASE_BREDRLE("Bluetooth Device Get VERSION_INFO - Fail",
 		ACTION_SUCCESS(bluetooth_enable_action, NULL),
 		CALLBACK_STATE(CB_BT_ADAPTER_STATE_CHANGED, BT_STATE_ON),
-		ACTION_SUCCESS(emu_setup_powered_remote_action, NULL),
 		ACTION_SUCCESS(bt_start_discovery_action, NULL),
 		CALLBACK_STATE(CB_BT_DISCOVERY_STATE_CHANGED,
 							BT_DISCOVERY_STARTED),
+		ACTION_SUCCESS(emu_setup_powered_remote_action, NULL),
+		CALLBACK_DEVICE_FOUND(prop_emu_remote_any_default_set, 1),
 		ACTION_SUCCESS(bt_cancel_discovery_action, NULL),
 		CALLBACK_STATE(CB_BT_DISCOVERY_STATE_CHANGED,
 							BT_DISCOVERY_STOPPED),
@@ -819,10 +836,11 @@ static struct test_case test_cases[] = {
 	TEST_CASE_BREDRLE("Bluetooth Device Get FRIENDLY_NAME - Fail",
 		ACTION_SUCCESS(bluetooth_enable_action, NULL),
 		CALLBACK_STATE(CB_BT_ADAPTER_STATE_CHANGED, BT_STATE_ON),
-		ACTION_SUCCESS(emu_setup_powered_remote_action, NULL),
 		ACTION_SUCCESS(bt_start_discovery_action, NULL),
 		CALLBACK_STATE(CB_BT_DISCOVERY_STATE_CHANGED,
 							BT_DISCOVERY_STARTED),
+		ACTION_SUCCESS(emu_setup_powered_remote_action, NULL),
+		CALLBACK_DEVICE_FOUND(prop_emu_remote_any_default_set, 1),
 		ACTION_SUCCESS(bt_cancel_discovery_action, NULL),
 		CALLBACK_STATE(CB_BT_DISCOVERY_STATE_CHANGED,
 							BT_DISCOVERY_STOPPED),
@@ -832,10 +850,11 @@ static struct test_case test_cases[] = {
 	TEST_CASE_BREDRLE("Bluetooth Device Set FRIENDLY_NAME - Success",
 		ACTION_SUCCESS(bluetooth_enable_action, NULL),
 		CALLBACK_STATE(CB_BT_ADAPTER_STATE_CHANGED, BT_STATE_ON),
-		ACTION_SUCCESS(emu_setup_powered_remote_action, NULL),
 		ACTION_SUCCESS(bt_start_discovery_action, NULL),
 		CALLBACK_STATE(CB_BT_DISCOVERY_STATE_CHANGED,
 							BT_DISCOVERY_STARTED),
+		ACTION_SUCCESS(emu_setup_powered_remote_action, NULL),
+		CALLBACK_DEVICE_FOUND(prop_emu_remote_any_default_set, 1),
 		ACTION_SUCCESS(bt_cancel_discovery_action, NULL),
 		CALLBACK_STATE(CB_BT_DISCOVERY_STATE_CHANGED,
 							BT_DISCOVERY_STOPPED),
@@ -848,10 +867,11 @@ static struct test_case test_cases[] = {
 	TEST_CASE_BREDRLE("Bluetooth Device Set BDNAME - Fail",
 		ACTION_SUCCESS(bluetooth_enable_action, NULL),
 		CALLBACK_STATE(CB_BT_ADAPTER_STATE_CHANGED, BT_STATE_ON),
-		ACTION_SUCCESS(emu_setup_powered_remote_action, NULL),
 		ACTION_SUCCESS(bt_start_discovery_action, NULL),
 		CALLBACK_STATE(CB_BT_DISCOVERY_STATE_CHANGED,
 							BT_DISCOVERY_STARTED),
+		ACTION_SUCCESS(emu_setup_powered_remote_action, NULL),
+		CALLBACK_DEVICE_FOUND(prop_emu_remote_any_default_set, 1),
 		ACTION_SUCCESS(bt_cancel_discovery_action, NULL),
 		CALLBACK_STATE(CB_BT_DISCOVERY_STATE_CHANGED,
 							BT_DISCOVERY_STOPPED),
@@ -861,10 +881,11 @@ static struct test_case test_cases[] = {
 	TEST_CASE_BREDRLE("Bluetooth Device Set UUIDS - Fail",
 		ACTION_SUCCESS(bluetooth_enable_action, NULL),
 		CALLBACK_STATE(CB_BT_ADAPTER_STATE_CHANGED, BT_STATE_ON),
-		ACTION_SUCCESS(emu_setup_powered_remote_action, NULL),
 		ACTION_SUCCESS(bt_start_discovery_action, NULL),
 		CALLBACK_STATE(CB_BT_DISCOVERY_STATE_CHANGED,
 							BT_DISCOVERY_STARTED),
+		ACTION_SUCCESS(emu_setup_powered_remote_action, NULL),
+		CALLBACK_DEVICE_FOUND(prop_emu_remote_any_default_set, 1),
 		ACTION_SUCCESS(bt_cancel_discovery_action, NULL),
 		CALLBACK_STATE(CB_BT_DISCOVERY_STATE_CHANGED,
 							BT_DISCOVERY_STOPPED),
@@ -874,10 +895,11 @@ static struct test_case test_cases[] = {
 	TEST_CASE_BREDRLE("Bluetooth Device Set COD - Fail",
 		ACTION_SUCCESS(bluetooth_enable_action, NULL),
 		CALLBACK_STATE(CB_BT_ADAPTER_STATE_CHANGED, BT_STATE_ON),
-		ACTION_SUCCESS(emu_setup_powered_remote_action, NULL),
 		ACTION_SUCCESS(bt_start_discovery_action, NULL),
 		CALLBACK_STATE(CB_BT_DISCOVERY_STATE_CHANGED,
 							BT_DISCOVERY_STARTED),
+		ACTION_SUCCESS(emu_setup_powered_remote_action, NULL),
+		CALLBACK_DEVICE_FOUND(prop_emu_remote_any_default_set, 1),
 		ACTION_SUCCESS(bt_cancel_discovery_action, NULL),
 		CALLBACK_STATE(CB_BT_DISCOVERY_STATE_CHANGED,
 							BT_DISCOVERY_STOPPED),
@@ -887,10 +909,11 @@ static struct test_case test_cases[] = {
 	TEST_CASE_BREDRLE("Bluetooth Device Set TOD - Fail",
 		ACTION_SUCCESS(bluetooth_enable_action, NULL),
 		CALLBACK_STATE(CB_BT_ADAPTER_STATE_CHANGED, BT_STATE_ON),
-		ACTION_SUCCESS(emu_setup_powered_remote_action, NULL),
 		ACTION_SUCCESS(bt_start_discovery_action, NULL),
 		CALLBACK_STATE(CB_BT_DISCOVERY_STATE_CHANGED,
 							BT_DISCOVERY_STARTED),
+		ACTION_SUCCESS(emu_setup_powered_remote_action, NULL),
+		CALLBACK_DEVICE_FOUND(prop_emu_remote_any_default_set, 1),
 		ACTION_SUCCESS(bt_cancel_discovery_action, NULL),
 		CALLBACK_STATE(CB_BT_DISCOVERY_STATE_CHANGED,
 							BT_DISCOVERY_STOPPED),
@@ -900,10 +923,11 @@ static struct test_case test_cases[] = {
 	TEST_CASE_BREDRLE("Bluetooth Device Set RSSI - Fail",
 		ACTION_SUCCESS(bluetooth_enable_action, NULL),
 		CALLBACK_STATE(CB_BT_ADAPTER_STATE_CHANGED, BT_STATE_ON),
-		ACTION_SUCCESS(emu_setup_powered_remote_action, NULL),
 		ACTION_SUCCESS(bt_start_discovery_action, NULL),
 		CALLBACK_STATE(CB_BT_DISCOVERY_STATE_CHANGED,
 							BT_DISCOVERY_STARTED),
+		ACTION_SUCCESS(emu_setup_powered_remote_action, NULL),
+		CALLBACK_DEVICE_FOUND(prop_emu_remote_any_default_set, 1),
 		ACTION_SUCCESS(bt_cancel_discovery_action, NULL),
 		CALLBACK_STATE(CB_BT_DISCOVERY_STATE_CHANGED,
 							BT_DISCOVERY_STOPPED),
@@ -913,10 +937,11 @@ static struct test_case test_cases[] = {
 	TEST_CASE_BREDRLE("Bluetooth Device Set TIMESTAMP - Fail",
 		ACTION_SUCCESS(bluetooth_enable_action, NULL),
 		CALLBACK_STATE(CB_BT_ADAPTER_STATE_CHANGED, BT_STATE_ON),
-		ACTION_SUCCESS(emu_setup_powered_remote_action, NULL),
 		ACTION_SUCCESS(bt_start_discovery_action, NULL),
 		CALLBACK_STATE(CB_BT_DISCOVERY_STATE_CHANGED,
 							BT_DISCOVERY_STARTED),
+		ACTION_SUCCESS(emu_setup_powered_remote_action, NULL),
+		CALLBACK_DEVICE_FOUND(prop_emu_remote_any_default_set, 1),
 		ACTION_SUCCESS(bt_cancel_discovery_action, NULL),
 		CALLBACK_STATE(CB_BT_DISCOVERY_STATE_CHANGED,
 							BT_DISCOVERY_STOPPED),
@@ -926,10 +951,11 @@ static struct test_case test_cases[] = {
 	TEST_CASE_BREDRLE("Bluetooth Device Set BDADDR - Fail",
 		ACTION_SUCCESS(bluetooth_enable_action, NULL),
 		CALLBACK_STATE(CB_BT_ADAPTER_STATE_CHANGED, BT_STATE_ON),
-		ACTION_SUCCESS(emu_setup_powered_remote_action, NULL),
 		ACTION_SUCCESS(bt_start_discovery_action, NULL),
 		CALLBACK_STATE(CB_BT_DISCOVERY_STATE_CHANGED,
 							BT_DISCOVERY_STARTED),
+		ACTION_SUCCESS(emu_setup_powered_remote_action, NULL),
+		CALLBACK_DEVICE_FOUND(prop_emu_remote_any_default_set, 1),
 		ACTION_SUCCESS(bt_cancel_discovery_action, NULL),
 		CALLBACK_STATE(CB_BT_DISCOVERY_STATE_CHANGED,
 							BT_DISCOVERY_STOPPED),
@@ -939,10 +965,11 @@ static struct test_case test_cases[] = {
 	TEST_CASE_BREDRLE("Bluetooth Device Set SERVICE_RECORD - Fail",
 		ACTION_SUCCESS(bluetooth_enable_action, NULL),
 		CALLBACK_STATE(CB_BT_ADAPTER_STATE_CHANGED, BT_STATE_ON),
-		ACTION_SUCCESS(emu_setup_powered_remote_action, NULL),
 		ACTION_SUCCESS(bt_start_discovery_action, NULL),
 		CALLBACK_STATE(CB_BT_DISCOVERY_STATE_CHANGED,
 							BT_DISCOVERY_STARTED),
+		ACTION_SUCCESS(emu_setup_powered_remote_action, NULL),
+		CALLBACK_DEVICE_FOUND(prop_emu_remote_any_default_set, 1),
 		ACTION_SUCCESS(bt_cancel_discovery_action, NULL),
 		CALLBACK_STATE(CB_BT_DISCOVERY_STATE_CHANGED,
 							BT_DISCOVERY_STOPPED),
@@ -952,10 +979,11 @@ static struct test_case test_cases[] = {
 	TEST_CASE_BREDRLE("Bluetooth Device Set SCAN_MODE - Fail",
 		ACTION_SUCCESS(bluetooth_enable_action, NULL),
 		CALLBACK_STATE(CB_BT_ADAPTER_STATE_CHANGED, BT_STATE_ON),
-		ACTION_SUCCESS(emu_setup_powered_remote_action, NULL),
 		ACTION_SUCCESS(bt_start_discovery_action, NULL),
 		CALLBACK_STATE(CB_BT_DISCOVERY_STATE_CHANGED,
 							BT_DISCOVERY_STARTED),
+		ACTION_SUCCESS(emu_setup_powered_remote_action, NULL),
+		CALLBACK_DEVICE_FOUND(prop_emu_remote_any_default_set, 1),
 		ACTION_SUCCESS(bt_cancel_discovery_action, NULL),
 		CALLBACK_STATE(CB_BT_DISCOVERY_STATE_CHANGED,
 							BT_DISCOVERY_STOPPED),
@@ -965,10 +993,11 @@ static struct test_case test_cases[] = {
 	TEST_CASE_BREDRLE("Bluetooth Device Set BONDED_DEVICES - Fail",
 		ACTION_SUCCESS(bluetooth_enable_action, NULL),
 		CALLBACK_STATE(CB_BT_ADAPTER_STATE_CHANGED, BT_STATE_ON),
-		ACTION_SUCCESS(emu_setup_powered_remote_action, NULL),
 		ACTION_SUCCESS(bt_start_discovery_action, NULL),
 		CALLBACK_STATE(CB_BT_DISCOVERY_STATE_CHANGED,
 							BT_DISCOVERY_STARTED),
+		ACTION_SUCCESS(emu_setup_powered_remote_action, NULL),
+		CALLBACK_DEVICE_FOUND(prop_emu_remote_any_default_set, 1),
 		ACTION_SUCCESS(bt_cancel_discovery_action, NULL),
 		CALLBACK_STATE(CB_BT_DISCOVERY_STATE_CHANGED,
 							BT_DISCOVERY_STOPPED),
@@ -978,10 +1007,11 @@ static struct test_case test_cases[] = {
 	TEST_CASE_BREDRLE("Bluetooth Device Set DISCOVERY_TIMEOUT - Fail",
 		ACTION_SUCCESS(bluetooth_enable_action, NULL),
 		CALLBACK_STATE(CB_BT_ADAPTER_STATE_CHANGED, BT_STATE_ON),
-		ACTION_SUCCESS(emu_setup_powered_remote_action, NULL),
 		ACTION_SUCCESS(bt_start_discovery_action, NULL),
 		CALLBACK_STATE(CB_BT_DISCOVERY_STATE_CHANGED,
 							BT_DISCOVERY_STARTED),
+		ACTION_SUCCESS(emu_setup_powered_remote_action, NULL),
+		CALLBACK_DEVICE_FOUND(prop_emu_remote_any_default_set, 1),
 		ACTION_SUCCESS(bt_cancel_discovery_action, NULL),
 		CALLBACK_STATE(CB_BT_DISCOVERY_STATE_CHANGED,
 							BT_DISCOVERY_STOPPED),
@@ -991,12 +1021,12 @@ static struct test_case test_cases[] = {
 	TEST_CASE_BREDR("Bluetooth Create Bond PIN - Success",
 		ACTION_SUCCESS(bluetooth_enable_action, NULL),
 		CALLBACK_STATE(CB_BT_ADAPTER_STATE_CHANGED, BT_STATE_ON),
-		ACTION_SUCCESS(emu_setup_powered_remote_action, NULL),
 		ACTION_SUCCESS(emu_set_pin_code_action, &emu_pin_set_req),
 		ACTION_SUCCESS(bt_start_discovery_action, NULL),
 		CALLBACK_STATE(CB_BT_DISCOVERY_STATE_CHANGED,
 							BT_DISCOVERY_STARTED),
-		CALLBACK_DEVICE_FOUND(prop_emu_remotes_default_set, 3),
+		ACTION_SUCCESS(emu_setup_powered_remote_action, NULL),
+		CALLBACK_DEVICE_FOUND(prop_emu_remote_bredr_default_set, 3),
 		ACTION_SUCCESS(bt_cancel_discovery_action, NULL),
 		CALLBACK_STATE(CB_BT_DISCOVERY_STATE_CHANGED,
 							BT_DISCOVERY_STOPPED),
@@ -1014,12 +1044,12 @@ static struct test_case test_cases[] = {
 	TEST_CASE_BREDR("Bluetooth Create Bond PIN - Bad PIN",
 		ACTION_SUCCESS(bluetooth_enable_action, NULL),
 		CALLBACK_STATE(CB_BT_ADAPTER_STATE_CHANGED, BT_STATE_ON),
-		ACTION_SUCCESS(emu_setup_powered_remote_action, NULL),
 		ACTION_SUCCESS(emu_set_pin_code_action, &emu_pin_set_req),
 		ACTION_SUCCESS(bt_start_discovery_action, NULL),
 		CALLBACK_STATE(CB_BT_DISCOVERY_STATE_CHANGED,
 							BT_DISCOVERY_STARTED),
-		CALLBACK_DEVICE_FOUND(prop_emu_remotes_default_set, 3),
+		ACTION_SUCCESS(emu_setup_powered_remote_action, NULL),
+		CALLBACK_DEVICE_FOUND(prop_emu_remote_bredr_default_set, 3),
 		ACTION_SUCCESS(bt_cancel_discovery_action, NULL),
 		CALLBACK_STATE(CB_BT_DISCOVERY_STATE_CHANGED,
 							BT_DISCOVERY_STOPPED),
@@ -1038,13 +1068,13 @@ static struct test_case test_cases[] = {
 	TEST_CASE_BREDR("Bluetooth Create Bond SSP -Success",
 		ACTION_SUCCESS(bluetooth_enable_action, NULL),
 		CALLBACK_STATE(CB_BT_ADAPTER_STATE_CHANGED, BT_STATE_ON),
-		ACTION_SUCCESS(emu_setup_powered_remote_action, NULL),
 		ACTION_SUCCESS(emu_set_ssp_mode_action, NULL),
 		ACTION_SUCCESS(emu_set_io_cap, &display_yes_no_io_cap),
 		ACTION_SUCCESS(bt_start_discovery_action, NULL),
 		CALLBACK_STATE(CB_BT_DISCOVERY_STATE_CHANGED,
 							BT_DISCOVERY_STARTED),
-		CALLBACK_DEVICE_FOUND(prop_emu_remotes_default_set, 3),
+		ACTION_SUCCESS(emu_setup_powered_remote_action, NULL),
+		CALLBACK_DEVICE_FOUND(prop_emu_remote_bredr_default_set, 3),
 		ACTION_SUCCESS(bt_cancel_discovery_action, NULL),
 		CALLBACK_STATE(CB_BT_DISCOVERY_STATE_CHANGED,
 							BT_DISCOVERY_STOPPED),
@@ -1062,13 +1092,13 @@ static struct test_case test_cases[] = {
 	TEST_CASE_BREDR("Bluetooth Create Bond SSP - Negative reply",
 		ACTION_SUCCESS(bluetooth_enable_action, NULL),
 		CALLBACK_STATE(CB_BT_ADAPTER_STATE_CHANGED, BT_STATE_ON),
-		ACTION_SUCCESS(emu_setup_powered_remote_action, NULL),
 		ACTION_SUCCESS(emu_set_ssp_mode_action, NULL),
 		ACTION_SUCCESS(emu_set_io_cap, &display_yes_no_io_cap),
 		ACTION_SUCCESS(bt_start_discovery_action, NULL),
 		CALLBACK_STATE(CB_BT_DISCOVERY_STATE_CHANGED,
 							BT_DISCOVERY_STARTED),
-		CALLBACK_DEVICE_FOUND(prop_emu_remotes_default_set, 3),
+		ACTION_SUCCESS(emu_setup_powered_remote_action, NULL),
+		CALLBACK_DEVICE_FOUND(prop_emu_remote_bredr_default_set, 3),
 		ACTION_SUCCESS(bt_cancel_discovery_action, NULL),
 		CALLBACK_STATE(CB_BT_DISCOVERY_STATE_CHANGED,
 							BT_DISCOVERY_STOPPED),
@@ -1120,13 +1150,13 @@ static struct test_case test_cases[] = {
 	TEST_CASE_BREDR("Bluetooth Cancel Bonding - Success",
 		ACTION_SUCCESS(bluetooth_enable_action, NULL),
 		CALLBACK_STATE(CB_BT_ADAPTER_STATE_CHANGED, BT_STATE_ON),
-		ACTION_SUCCESS(emu_setup_powered_remote_action, NULL),
 		ACTION_SUCCESS(emu_set_ssp_mode_action, NULL),
 		ACTION_SUCCESS(emu_set_io_cap, &display_yes_no_io_cap),
 		ACTION_SUCCESS(bt_start_discovery_action, NULL),
 		CALLBACK_STATE(CB_BT_DISCOVERY_STATE_CHANGED,
 							BT_DISCOVERY_STARTED),
-		CALLBACK_DEVICE_FOUND(prop_emu_remotes_default_set, 3),
+		ACTION_SUCCESS(emu_setup_powered_remote_action, NULL),
+		CALLBACK_DEVICE_FOUND(prop_emu_remote_bredr_default_set, 3),
 		ACTION_SUCCESS(bt_cancel_discovery_action, NULL),
 		CALLBACK_STATE(CB_BT_DISCOVERY_STATE_CHANGED,
 							BT_DISCOVERY_STOPPED),
@@ -1146,13 +1176,13 @@ static struct test_case test_cases[] = {
 	TEST_CASE_BREDR("Bluetooth Remove Bond - Success",
 		ACTION_SUCCESS(bluetooth_enable_action, NULL),
 		CALLBACK_STATE(CB_BT_ADAPTER_STATE_CHANGED, BT_STATE_ON),
-		ACTION_SUCCESS(emu_setup_powered_remote_action, NULL),
 		ACTION_SUCCESS(emu_set_ssp_mode_action, NULL),
 		ACTION_SUCCESS(emu_set_io_cap, &display_yes_no_io_cap),
 		ACTION_SUCCESS(bt_start_discovery_action, NULL),
 		CALLBACK_STATE(CB_BT_DISCOVERY_STATE_CHANGED,
 							BT_DISCOVERY_STARTED),
-		CALLBACK_DEVICE_FOUND(prop_emu_remotes_default_set, 3),
+		ACTION_SUCCESS(emu_setup_powered_remote_action, NULL),
+		CALLBACK_DEVICE_FOUND(prop_emu_remote_bredr_default_set, 3),
 		ACTION_SUCCESS(bt_cancel_discovery_action, NULL),
 		CALLBACK_STATE(CB_BT_DISCOVERY_STATE_CHANGED,
 							BT_DISCOVERY_STOPPED),
