@@ -34,13 +34,14 @@
 #include <assert.h>
 #include <signal.h>
 #include <sys/socket.h>
+
 #include <glib.h>
 
-#include <bluetooth/bluetooth.h>
-#include <bluetooth/sdp.h>
-#include <bluetooth/sdp_lib.h>
+#include "lib/bluetooth.h"
+#include "lib/sdp.h"
+#include "lib/sdp_lib.h"
 
-#include <gdbus/gdbus.h>
+#include "gdbus/gdbus.h"
 
 #include "cups.h"
 
@@ -705,7 +706,7 @@ int main(int argc, char *argv[])
 	bdaddr_t bdaddr;
 	unsigned short ctrl_psm, data_psm;
 	uint8_t channel, b[6];
-	char *ptr, str[3], device[18], service[12];
+	char *ptr, str[3], device[18], service[13];
 	const char *uri, *cups_class;
 	int i, err, fd, copies, proto;
 
