@@ -998,7 +998,8 @@ static void report_map_read_cb(guint8 status, const guint8 *pdu, guint16 plen,
 		return;
 	}
 
-	strncpy((char *) ev.u.create.name, hog->name, sizeof(ev.u.create.name));
+	strncpy((char *) ev.u.create.name, hog->name,
+						sizeof(ev.u.create.name) - 1);
 	ev.u.create.vendor = hog->vendor;
 	ev.u.create.product = hog->product;
 	ev.u.create.version = hog->version;
