@@ -27,6 +27,11 @@ typedef void (*queue_destroy_func_t)(void *data);
 
 struct queue;
 
+struct queue_entry {
+	void *data;
+	struct queue_entry *next;
+};
+
 struct queue *queue_new(void);
 void queue_destroy(struct queue *queue, queue_destroy_func_t destroy);
 
@@ -42,7 +47,7 @@ typedef void (*queue_foreach_func_t)(void *data, void *user_data);
 void queue_foreach(struct queue *queue, queue_foreach_func_t function,
 							void *user_data);
 
-typedef bool (*queue_match_func_t)(const void *a, const void *b);
+typedef bool (*queue_match_func_t)(const void *data, const void *match_data);
 
 void *queue_find(struct queue *queue, queue_match_func_t function,
 							const void *match_data);
@@ -53,5 +58,7 @@ void *queue_remove_if(struct queue *queue, queue_match_func_t function,
 unsigned int queue_remove_all(struct queue *queue, queue_match_func_t function,
 				void *user_data, queue_destroy_func_t destroy);
 
+const struct queue_entry *queue_get_entries(struct queue *queue);
+
 unsigned int queue_length(struct queue *queue);
 bool queue_isempty(struct queue *queue);
